@@ -74,3 +74,28 @@ def get_releases_for_a_project(client, project_id):
         raise ZAPIError(r)
 
     return r.json()
+
+
+# Create a release with the information passed in
+def update_release(client, release_id, release_spec):
+    # Get info on the release to fill the request.
+    release_info = client.get_release_by_release_id(release_id)
+
+    url = client.base_url + '/release/' + str(release_id)
+    headers = {
+        'Authorization': 'Bearer ' + client.token,
+        'Content-Type': 'application/json'
+    }
+
+    # Go through the request info, and replace any values in there with values
+    # from release spec.
+    for key, value in release_info.items():
+        if key not in release_spec:
+            release_spec[key] = value
+
+    # Otherwise make the API call.
+    r = requests.put(url, json=release_spec, headers=headers)
+    if r.status_code != 200:
+        raise ZAPIError(r)
+
+    return r.json()
