@@ -1,3 +1,4 @@
+from zephyr_sdk.components import cycles
 from zephyr_sdk.components import defects
 from zephyr_sdk.components import projects
 from zephyr_sdk.components import releases
@@ -18,12 +19,15 @@ class ZClient:
         self.base_url = url
 
         # Set user id for the API calls
-        self.user_id = self.get_current_logged_in_users()['id']
+        user_info = self.get_current_logged_in_users()
+        self.user_id = user_info['id']
+        self.user_name = user_info['username']
 
         # Properties that are undeclared for now
         self.project_id = None
         self.project_name = None
         self.release_id = None
+        self.release_name = None
         self.req_tree_id = None
         self.testcase_tree_id = None
 
@@ -52,6 +56,7 @@ class ZClient:
             # Set the release id and exit the function if found
             if release['name'] == release_name:
                 self.release_id = release['id']
+                self.release_name = release['name']
                 return
 
         # If the method got to this point, raise an exception
@@ -87,19 +92,47 @@ class ZClient:
 
         raise ResourceNotFoundError("Testcase Tree", tree_name)
 
+    # Cycle methods
+    def create_cycle(self, cycle_spec):
+        return cycles.create_cycle(self, cycle_spec)
+
+    def delete_cycle(self, cycle_id):
+        return cycles.delete_cycle(self, cycle_id)
+
+    def get_cycle_by_id(self, cycle_id):
+        return cycles.get_cycle_by_id(self, cycle_id)
+
+    def get_cycles_for_release(self, release_id):
+        return cycles.get_cycles_for_release(self, release_id)
+
+    def update_cycle(self, cycle_id, cycle_spec):
+        return cycles.update_cycle(self, cycle_id, cycle_spec)
+
     # Defects methods
     def create_defect(self, defect_spec):
         if 'projectId' not in defect_spec and self.project_id is not None:
             defect_spec['projectId'] = self.project_id
         if 'product' not in defect_spec and self.project_name is not None:
-            defect_spec['product'] = self.project_name
+            defect_spec['product'] = str(self.project_id)
+        if 'target_milestone' not in defect_spec and self.release_name is not None:
+            defect_spec['target_milestone'] = self.release_name
+        if 'version' not in defect_spec and self.release_id is not None:
+            defect_spec['version'] = str(self.release_id)
+        if 'assigned_to' not in defect_spec:
+            defect_spec['assigned_to'] = self.user_name
         return defects.create_defect(self, defect_spec)
 
     def delete_defect(self, defect_id):
         return defects.delete_defect(self, defect_id)
 
-    def get_defects(self):
-        return defects.get_defects(self)
+    def get_component(self, component_name, project_id=None):
+        if project_id is None:
+            return defects.get_component(self, component_name, self.project_id)
+        else:
+            return defects.get_component(self, component_name, project_id)
+
+    def get_defect(self, defect_id):
+        return defects.get_defect(self, defect_id)
 
     # Projects methods
     def get_all_normal_projects_details(self):
@@ -161,6 +194,12 @@ class ZClient:
         else:
             return releases.get_releases_for_a_project(self, project_id)
 
+    def update_release(self, release_spec, release_id=None):
+        if release_id is None:
+            return releases.update_release(self, release_spec, self.release_id)
+        else:
+            return releases.update_release(self, release_spec, release_id)
+
     # Requirements methods
     def create_requirement(self, requirement_spec):
         if 'requirementTreeId' not in requirement_spec and self.req_tree_id is not None:
@@ -212,9 +251,18 @@ class ZClient:
 
         return testcases.create_testcase(self, testcase_spec)
 
+    def delete_testcase(self, testcase_id):
+        return testcases.delete_testcase(self, testcase_id)
+
+    def get_testcase_by_id(self, testcase_id):
+        return testcases.get_testcase_by_id(self, testcase_id)
+
     def map_testcase_to_requirements(self, map_spec):
         return testcases.map_testcase_to_requirements(self, map_spec)
 
+    def update_testcase(self, testcase_id, testcase_spec):
+        return testcases.update_testcase(self, testcase_id, testcase_spec)
+
     # Testcase tree methods
     def get_testcase_tree_by_release_id(self, release_id=None):
         if release_id is None:
